<?php

namespace App\Http\Requests;

use App\About;
use Illuminate\Contracts\Validation\Validator;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Http\Exceptions\HttpResponseException;

class AboutRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    protected function failedValidation(Validator $validator)
    {
        $result = ['status' => 'error' ,'data' => implode("<br>" , $validator->errors()->all())];

        throw new HttpResponseException(response()->json($result , 200));
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        return [
            'title1' => 'required',
            'title2' => 'required',
            'description1' => 'required',
            'description2' => 'required',
            'counter1' => 'required|numeric',
            'counter2' => 'required|numeric',
            'counter3' => 'required|numeric',
            'countries' => 'required',
            'experts' => 'required',
            'engagement' => 'required'
        ];
    }

    public function messages()
    {
        return [
            'title1.required' => 'Please enter the first head title',
            'title2.required' => 'Please enter the second head title',
            'description1.required' => 'Please enter the first description',
            'description2.required' => 'Please enter the second description',
            'counter1.required' => 'Please enter the first counter',
            'counter1.numeric' => 'First counter should be numbers',
            'countries.required' => 'Please enter first counter title',
            'counter2.required' => 'Please enter the second counter',
            'counter2.numeric' => 'Second counter should be numbers',
            'experts.required' => 'Please enter second counter title',
            'counter3.required' => 'Please enter the third counter',
            'counter3.numeric' => 'Third counter should be numbers',
            'engagement.required' => 'Please enter third counter title'
        ];
    }

    public function edit()
    {
        $about = About::first();

        $about->title1 = $this->title1;
        $about->title2 = $this->title2;
        $about->description1 = $this->description1;
        $about->description2 = $this->description2;
        $about->counter1 = $this->counter1;
        $about->countries = $this->countries;
        $about->counter2 = $this->counter2;
        $about->experts = $this->experts;
        $about->counter3 = $this->counter3;
        $about->engagement = $this->engagement;

        $about->save();
    }
}
