<?php

namespace App\Http\Requests;

use App\Therapy;
use Illuminate\Contracts\Validation\Validator;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Http\Exceptions\HttpResponseException;
use Illuminate\Support\Facades\Request;
use Intervention\Image\Facades\Image;

class TherapyRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    protected function failedValidation(Validator $validator)
    {
        $result = ['status' => 'error' ,'data' => implode("<br>" , $validator->errors()->all())];

        throw new HttpResponseException(response()->json($result , 200));
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        if (Request::route()->getName() == 'admin.therapy'){
            return [
                'name' => 'required',
                'description' => 'required',
                'image' => 'required|image|mimes:jpeg,jpg,png,gif,svg|max:20000'
            ];
        }else{
            return [
                'name' => 'required',
                'description' => 'required',
                'image' => 'image|mimes:jpeg,jpg,png,gif,svg|max:20000'
            ];
        }
    }

    public function messages()
    {
        if (Request::route()->getName() == 'admin.therapy'){
            return [
                'name.required' => 'Please enter name',
                'description.required' => 'Please enter details',
                'image.required' => 'Please select an image',
                'image.image' => 'You can select only images',
                'image.mimes' => 'image type should be : jpeg,jpg,png,gif,svg',
                'image.max' => 'Maximum size allowed for image is 2MB',
            ];
        }else{
            return [
                'name.required' => 'Please enter name',
                'description.required' => 'Please enter details',
                'image.image' => 'You can select only images',
                'image.mimes' => 'image type should be : jpeg,jpg,png,gif,svg',
                'image.max' => 'Maximum size allowed for image is 2MB',
            ];
        }
    }

    public function store()
    {
        $therapy = new Therapy();
        
        $therapy->name = $this->name;
        $therapy->description = $this->description;

        $file = $this->image;
        $destination = storage_path('uploads/therapy');

        if (!empty($file)) {
//            @unlink($destination . "/{$settings->image}");
            $therapy->image= md5(time()).'.'.$file->getClientOriginalName();
            $this->image->move($destination, $therapy->image);
            Image::make($destination.'/'.$therapy->image)
                ->resize(240,166)
                ->save($destination.'/'.$therapy->image);
        }

        $therapy->save();
    }

    public function edit($id)
    {
        $therapy = Therapy::find($id);

        $therapy->name = $this->name;
        $therapy->description = $this->description;

        $file = $this->image;
        $destination = storage_path('uploads/therapy');

        if (!empty($file)) {
            @unlink($destination . "/{$therapy->image}");
            $therapy->image= md5(time()).'.'.$file->getClientOriginalName();
            $this->image->move($destination, $therapy->image);
            Image::make($destination.'/'.$therapy->image)
                ->resize(240,166)
                ->save($destination.'/'.$therapy->image);
        }

        $therapy->save();
    }
}
