<?php

namespace App\Http\Requests;

use App\Setting;
use Illuminate\Contracts\Validation\Validator;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Http\Exceptions\HttpResponseException;
use Image;

class SettingRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    protected function failedValidation(Validator $validator)
    {
        $result = ['status' => 'error' ,'data' => implode("<br>" , $validator->errors()->all())];

        throw new HttpResponseException(response()->json($result , 200));
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        return [
            'name' => 'required',
            'logo' => 'mimes:jpeg,jpg,png,gif,svg|max:20000'
        ];
    }

    public function messages()
    {
        return [
            'name.required' => 'Please enter site name',
            'logo.mimes' => 'logo type should be : jpeg,jpg,png,gif,svg',
            'logo.max' => 'Maximum size allowed for logo is 2MB',
        ];
    }

    public function edit(){
        $settings = Setting::first();

        $settings->name = $this->name;

        $file = $this->logo;
        $destination = storage_path('uploads/logo');

        if (!empty($file)) {
            @unlink($destination . "/{$settings->logo}");
            $settings->logo= md5(time()).'.'.$file->getClientOriginalName();
            $this->logo->move($destination, $settings->logo);
            \Intervention\Image\Facades\Image::make($destination.'/'.$settings->logo)
                ->resize(240,60)
                ->save($destination.'/'.$settings->logo);
        }

        $settings->save();
    }
}
