<?php

namespace App\Http\Requests;

use App\Contact;
use Illuminate\Contracts\Validation\Validator;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Http\Exceptions\HttpResponseException;

class ContactRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    protected function failedValidation(Validator $validator)
    {
        $result = ['status' => 'error' ,'data' => implode("<br>" , $validator->errors()->all())];

        throw new HttpResponseException(response()->json($result , 200));
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        return [
            'email' => 'required',
            'firstAddressSection1' => 'required',
            'firstAddressSection2' => 'required',
            'secondAddressSection1' => 'required',
            'secondAddressSection2' => 'required',
            'thirdAddressSection1' => 'required',
            'thirdAddressSection2' => 'required'
        ];
    }

    public function messages()
    {
        return [
            'email.required' => 'Please enter site email',
            'firstAddressSection1.required' => 'Please enter first address country name',
            'firstAddressSection2.required' => 'Please enter first address',
            'secondAddressSection1.required' => 'Please enter second address country name',
            'secondAddressSection2.required' => 'Please enter second address',
            'thirdAddressSection1.required' => 'Please enter third address country name',
            'thirdAddressSection2.required' => 'Please enter third address'
        ];
    }

    public function edit()
    {
        $contact = Contact::first();

        $contact->email = $this->email;
        $contact->firstAddressSection1 = $this->firstAddressSection1;
        $contact->firstAddressSection2 = $this->firstAddressSection2;
        $contact->secondAddressSection1 = $this->secondAddressSection1;
        $contact->secondAddressSection2 = $this->secondAddressSection2;
        $contact->thirdAddressSection1 = $this->thirdAddressSection1;
        $contact->thirdAddressSection2 = $this->thirdAddressSection2;

        $contact->save();
    }
}
