<?php

namespace App\Http\Requests;

use App\Mail\SendMailMail;
use App\Message;
use Illuminate\Contracts\Validation\Validator;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Http\Exceptions\HttpResponseException;
use Mail;

class MessageRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    protected function failedValidation(Validator $validator)
    {
        $result = ['status' => 'error' ,'data' => implode("<br>" , $validator->errors()->all())];

        throw new HttpResponseException(response()->json($result , 200));
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        return [
            'message' => 'required',
            'ids' => 'required'
        ];
    }

    public function messages()
    {
        return [
            'ids.required' => 'Please select an email first',
            'message.required' => 'Please enter your message'
        ];
    }

    public function send()
    {
        $ids = $this->input('ids');

        foreach (explode("," , $ids) as $id) {
            if ($id != "on"){
                $member = Message::find($id);

                \Illuminate\Support\Facades\Mail::to($member->email)->send(new SendMailMail($this->message , $member->name));
            }

        }

        return ['response' => 'success' ,'message' => 'An email has been sent successfully'];
    }
}
