<?php


Route::get('/privacynotice/meresearch', function () {
    return view('site.pages.meresearch.index');
});


/**
 * Adminpanel routes
 */
Route::group(['namespace' => 'Admin' ,'prefix' => 'admin'] ,function (){

    Route::group(['namespace' => 'Auth'] ,function (){
        Route::get('/login' ,['as' => 'admin.auth' ,'uses' => 'LoginController@getLogin']);
        Route::post('/login' ,['as' => 'admin.auth' ,'uses' => 'LoginController@postLogin']);
        Route::get('/logout', 'LoginController@getLogout')->name('admin.logout');
    });

    Route::group(['middleware' => 'auth.admin'] ,function (){

        //dashboard route
        Route::get('/' ,['as' => 'admin.dashboard' ,'uses' => 'DashboardController@getIndex']);

        /**
         * settings routes
         */
        Route::group(['prefix' => 'settings'] ,function (){
            Route::get('/' ,['as' => 'admin.settings' ,'uses' => 'SettingController@getIndex']);
            Route::post('/' ,['as' => 'admin.settings' ,'uses' => 'SettingController@postIndex']);
            Route::post('/therapy' ,['as' => 'admin.settings.therapy' ,'uses' => 'TherapyController@postEditTitle']);
        });

        /**
         * about routes
         */
        Route::group(['prefix' => 'about'] ,function (){
            Route::get('/' ,['as' => 'admin.about' ,'uses' => 'AboutController@getIndex']);
            Route::post('/' ,['as' => 'admin.about' ,'uses' => 'AboutController@postIndex']);
        });

        /**
         * contact routes
         */
        Route::group(['prefix' => 'contact-us'] ,function (){
            Route::get('/' ,['as' => 'admin.contact' ,'uses' => 'ContactController@getIndex']);
            Route::post('/' ,['as' => 'admin.contact' ,'uses' => 'ContactController@postIndex']);
        });

        /**
         * slider routes
         */
        Route::group(['prefix' => 'slider' ] ,function (){
            Route::get('/' ,['as' => 'admin.sliders' ,'uses' => 'DashboardController@getIndex']);
            Route::post('/' ,['as' => 'admin.sliders' ,'uses' => 'DashboardController@postIndex']);
            Route::post('/edit/{id}' ,['as' => 'admin.sliders.edit' ,'uses' => 'DashboardController@postEdit']);
            Route::get('/delete/{id}' ,['as' => 'admin.sliders.delete' ,'uses' => 'DashboardController@getDelete']);
        });

        /**
         * messages routes
         */
        Route::group(['prefix' => 'messages'] ,function (){
            Route::get('/' ,['as' => 'admin.messages' ,'uses' => 'MessageController@getIndex']);
            Route::post('/' ,['as' => 'admin.messages.send' ,'uses' => 'MessageController@postIndex']);
        });

        /**
         * users routes
         */
        Route::group(['prefix' => 'users'] ,function (){
            Route::get('/' ,['as' => 'admin.users' ,'uses' => 'UserController@getIndex']);
            Route::post('/' ,['as' => 'admin.users' ,'uses' => 'UserController@postIndex']);
            Route::post('/edit/{id}' ,['as' => 'admin.users.edit' ,'uses' => 'UserController@postEdit']);
            Route::get('/delete/{id}' ,['as' => 'admin.users.delete' ,'uses' => 'UserController@getDelete']);
        });

        /**
         * soltuions routes
         */
        Route::group(['prefix' => 'our-solutions'] ,function (){
            Route::get('/' ,['as' => 'admin.solutions' ,'uses' => 'SolutionController@getIndex']);
            Route::post('/' ,['as' => 'admin.solutions' ,'uses' => 'SolutionController@postIndex']);
            Route::get('/edit/{id}' ,['as' => 'admin.solutions.edit' ,'uses' => 'SolutionController@getEdit']);
            Route::post('/edit/{id}' ,['as' => 'admin.solutions.edit' ,'uses' => 'SolutionController@postEdit']);
            Route::get('/delete/{id}' ,['as' => 'admin.solutions.delete' ,'uses' => 'SolutionController@getDelete']);
        });

        /**
         * geographic routes
         */
        Route::group(['prefix' => 'geographic'] ,function (){
            Route::get('/' ,['as' => 'admin.geographic' ,'uses' => 'GeographicController@getIndex']);
            Route::post('/' ,['as' => 'admin.geographic' ,'uses' => 'GeographicController@postIndex']);
        });

        /**
         * therapy routes
         */
        Route::group(['prefix' => 'therapy'] ,function (){
            Route::get('/' ,['as' => 'admin.therapy' ,'uses' => 'TherapyController@getIndex']);
            Route::post('/' ,['as' => 'admin.therapy' ,'uses' => 'TherapyController@postIndex']);
            Route::post('/edit/{id}' ,['as' => 'admin.therapy.edit' ,'uses' => 'TherapyController@postEdit']);
            Route::get('/delete/{id}' ,['as' => 'admin.therapy.delete' ,'uses' => 'TherapyController@getDelete']);
        });
    });
});

//site routes
Route::group(['namespace' => 'Site'] ,function (){
    //home route
    Route::get('/' ,['as' => 'site.home' ,'uses' => 'HomeController@getIndex']);
    
    Route::get('/privacynotice/meresearch/', 'HomeController@search');
    //about route
    Route::get('/about-us' ,['as' => 'site.about' ,'uses' => 'AboutController@getIndex']);

    //solutions route
    Route::get('/our-solutions' ,['as' => 'site.solutions' ,'uses' => 'SolutionController@getIndex']);
    Route::get('/our-solutions/{name}' ,['as' => 'site.solutions.single' ,'uses' => 'SolutionController@getSingleSolution']);


    //expertise routes
    Route::get('/expertise' ,['as' => 'site.expertise' ,'uses' => 'ExpertiseController@getIndex']);
    Route::get('/expertise/geographic' ,['as' => 'site.expertise.geographic' ,'uses' => 'ExpertiseController@getGeographic']);
    Route::get('/expertise/therapy' ,['as' => 'site.expertise.therapy' ,'uses' => 'ExpertiseController@getTherapy']);

    //contact us routes
    Route::get('/contact-us' ,['as' => 'site.contact' ,'uses' => 'ContactUSController@getIndex']);
    Route::post('/contact-us/send' ,['as' => 'site.contact.send' ,'uses' => 'ContactUSController@postIndex']);
});
